Internal namespace, wrapping some goog.math.Long functionality.
Internal namespace, wrapping some goog.math.Long functionality.
(* x y)(+ x y)(->long x)Coerces to long, or returns nil if not possible.
Coerces to long, or returns nil if not possible.
(bit-or x y)(bit-xor x y)(from-number x)(from-string s radix)(unsigned-bit-shift-right x n)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |